<?php
/**
 * Joomla用定義ファイル
 *
 * 機能：Joomlaの定義を管理
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2008 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id$
 * @link       http://www.magic3.org
 */
// Joomla用定義
define( '_VALID_MOS', 1 );
DEFINE('_DATE_FORMAT_LC',"%A, %d %B %Y"); //Uses PHP's strftime Command Format
//DEFINE('_ISO','charset=iso-8859-1');
DEFINE('_ISO','charset=utf-8');

// Joomla用グローバル変数
$mosConfig_absolute_path = $gEnvManager->getJoomlaRootPath();
$mosConfig_live_site = $gEnvManager->getRootUrl();
$mosConfig_sitename = $gEnvManager->getSiteName();// サイト名称
$mosConfig_favicon = 'favicon.ico';
$mosConfig_sef = '0';
$cur_template = $gEnvManager->getCurrentTemplateId();

// グローバルオブジェクト
class mosMainFrame {
	function getTemplate(){
		global $cur_template;
		return $cur_template;
	}
}
$mainframe = new mosMainFrame();
?>
